using AipGateway.AIP;

namespace AipGateway.API.Service.Services
{
    public interface IAipFileManagerService
    {
        Task<AipConfig> GetConfig();
        Task<List<AipLabel>> GetLabels();
        Task<List<AipLabel>> GetPolicies();
        Task<List<AipTemplate>> GetProtections();

        Task<AipFileInfo> GetFileInfo(string fileName);
        Task<AipFileInfo> GetFileInfo(Stream streamArr);
    }
}
